<?php
/**
 * Copyright 2011-2023 Twinkle Toes Software, LLC
 */

require_once('Language.php');

class en_us extends Language
{
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * @return array
     */
    protected function _LoadDates()
    {
        $dates = [];

        $dates['general_date'] = 'm/d/Y';
        $dates['short_date'] = 'n/j/y';
        $dates['general_datetime'] = 'm/d/Y g:i:s A';
        $dates['short_datetime'] = 'n/j/y g:i A';
        $dates['schedule_daily'] = 'l, n/j/y';
        $dates['reservation_email'] = 'm/d/Y @ g:i A (e)';
        $dates['res_popup'] = 'D, n/d g:i A';
        $dates['res_popup_time'] = 'g:i A';
        $dates['short_reservation_date'] = 'n/j/y g:i A';
        $dates['dashboard'] = 'D, n/d g:i A';
        $dates['period_time'] = 'g:i A';
        $dates['timepicker'] = 'g:i A';
        $dates['mobile_reservation_date'] = 'n/j g:i A';
        $dates['general_date_js'] = 'mm/dd/yy';
        $dates['general_time_js'] = 'h:mm tt';
        $dates['timepicker_js'] = 'h:i a';
        $dates['momentjs_datetime'] = 'M/D/YY h:mm A';
        $dates['calendar_time'] = 'h:mma';
        $dates['calendar_dates'] = 'M d';
        $dates['embedded_date'] = 'D d';
        $dates['embedded_time'] = 'g:i A';
        $dates['embedded_datetime'] = 'n/j g:i A';
        $dates['report_date'] = '%m/%d';
        $dates['react_date'] = 'MM/dd/yyyy'; // date-fns format
        $dates['react_time'] = 'hh:mm aaa'; // date-fns format
        $dates['react_datetime'] = 'M/d/yy h:mm aaa'; // date-fns format
        $dates['monitor_date'] = 'n/j/y';
        $dates['monitor_time'] = 'g:i A';
        $dates['monitor_event_date'] = 'n/j';
        $dates['monitor_event_time'] = 'g:ia';
        $dates['sms_datetime'] = 'n/j g:i a';

        $this->Dates = $dates;

        return $this->Dates;
    }

    /**
     * @return array
     */
    protected function _LoadStrings()
    {
        $strings = array();

        $strings['FirstName'] = 'First Name';
        $strings['LastName'] = 'Last Name';
        $strings['Timezone'] = 'Timezone';
        $strings['Edit'] = 'Edit';
        $strings['Change'] = 'Change';
        $strings['Rename'] = 'Rename';
        $strings['Remove'] = 'Remove';
        $strings['Delete'] = 'Delete';
        $strings['Update'] = 'Update';
        $strings['Cancel'] = 'Cancel';
        $strings['Add'] = 'Add';
        $strings['Name'] = 'Name';
        $strings['Yes'] = 'Yes';
        $strings['No'] = 'No';
        $strings['FirstNameRequired'] = 'First name is required.';
        $strings['LastNameRequired'] = 'Last name is required.';
        $strings['PwMustMatch'] = 'Password confirmation must match password.';
        $strings['ValidEmailRequired'] = 'A valid email address is required.';
        $strings['UniqueEmailRequired'] = 'That email address is already registered.';
        $strings['UniqueUsernameRequired'] = 'That username is already registered.';
        $strings['UserNameRequired'] = 'Username is required.';
        $strings['CaptchaInvalid'] = 'The captcha security check failed.';
        $strings['Today'] = 'Today';
        $strings['Week'] = 'Week';
        $strings['Month'] = 'Month';
        $strings['BackToCalendar'] = 'Back to calendar';
        $strings['BeginDate'] = 'Begin';
        $strings['EndDate'] = 'End';
        $strings['Username'] = 'Username';
        $strings['Password'] = 'Password';
        $strings['PasswordConfirmation'] = 'Confirm Password';
        $strings['DefaultPage'] = 'Default Homepage';
        $strings['MyCalendar'] = 'My Calendar';
        $strings['ScheduleCalendar'] = 'Schedule Calendar';
        $strings['Registration'] = 'Registration';
        $strings['NoAnnouncements'] = 'There are no announcements';
        $strings['Announcements'] = 'Announcements';
        $strings['NoUpcomingReservations'] = 'You have no upcoming reservations';
        $strings['UpcomingReservations'] = 'Upcoming Reservations';
        $strings['AllNoUpcomingReservations'] = 'No upcoming reservations';
        $strings['AllUpcomingReservations'] = 'All Upcoming Reservations';
        $strings['ShowHide'] = 'Show/Hide';
        $strings['Error'] = 'Error';
        $strings['ReturnToPreviousPage'] = 'Return to the last page that you were on';
        $strings['UnknownError'] = 'Unknown Error';
        $strings['InsufficientPermissionsError'] = 'You do not have permission to access this resource';
        $strings['MissingReservationResourceError'] = 'A resource was not selected';
        $strings['MissingReservationScheduleError'] = 'A schedule was not selected';
        $strings['DoesNotRepeat'] = 'Does Not Repeat';
        $strings['Daily'] = 'Daily';
        $strings['Weekly'] = 'Weekly';
        $strings['Monthly'] = 'Monthly';
        $strings['Yearly'] = 'Yearly';
        $strings['RepeatPrompt'] = 'Repeat';
        $strings['hours'] = 'hours';
        $strings['days'] = 'days';
        $strings['weeks'] = 'weeks';
        $strings['months'] = 'months';
        $strings['years'] = 'years';
        $strings['day'] = 'day';
        $strings['week'] = 'week';
        $strings['month'] = 'month';
        $strings['year'] = 'year';
        $strings['repeatDayOfMonth'] = 'day of month';
        $strings['repeatDayOfWeek'] = 'day of week';
        $strings['RepeatUntilPrompt'] = 'Until';
        $strings['RepeatEveryPrompt'] = 'Every';
        $strings['RepeatDaysPrompt'] = 'on';
        $strings['CreateReservationHeading'] = 'New Reservation';
        $strings['EditReservationHeading'] = 'Editing Reservation %s';
        $strings['ViewReservationHeading'] = 'Viewing Reservation %s';
        $strings['ReservationErrors'] = 'Change Reservation';
        $strings['Create'] = 'Create';
        $strings['ThisInstance'] = 'Only This Instance';
        $strings['AllInstances'] = 'All Instances';
        $strings['FutureInstances'] = 'Future Instances';
        $strings['Print'] = 'Print';
        $strings['ShowHideNavigation'] = 'Show/Hide Navigation';
        $strings['ReferenceNumber'] = 'Reference Number';
        $strings['Tomorrow'] = 'Tomorrow';
        $strings['LaterThisWeek'] = 'Later This Week';
        $strings['NextWeek'] = 'Next Week';
        $strings['SignOut'] = 'Sign Out';
        $strings['LayoutDescription'] = 'Starts on %s, showing %s days at a time';
        $strings['AllResources'] = 'All Resources';
        $strings['TakeOffline'] = 'Take Offline';
        $strings['BringOnline'] = 'Bring Online';
        $strings['AddImage'] = 'Add Image';
        $strings['NoImage'] = 'No Image Assigned';
        $strings['Move'] = 'Move';
        $strings['AppearsOn'] = 'Appears On %s';
        $strings['Location'] = 'Location';
        $strings['NoLocationLabel'] = '(no location set)';
        $strings['Contact'] = 'Contact';
        $strings['NoContactLabel'] = '(no contact information)';
        $strings['Description'] = 'Description';
        $strings['NoDescriptionLabel'] = '(no description)';
        $strings['Notes'] = 'Notes';
        $strings['NoNotesLabel'] = '(no notes)';
        $strings['NoTitleLabel'] = '(no title)';
        $strings['UsageConfiguration'] = 'Usage Configuration';
        $strings['ChangeConfiguration'] = 'Change Configuration';
        $strings['ResourceMinLength'] = 'Reservations must last at least <strong>%s</strong>';
        $strings['ReservationsMustLastAtLeast'] = 'Reservations must last at least';
        $strings['ResourceMinLengthNone'] = 'There is <strong>no minimum</strong> reservation duration';
        $strings['ResourceMaxLength'] = 'Reservations cannot last more than <strong>%s</strong>';
        $strings['ReservationsCannotLastMoreThan'] = 'Reservations cannot last more than';
        $strings['ResourceMaxLengthNone'] = 'There is <strong>no maximum</strong> reservation duration';
        $strings['ResourceRequiresApproval'] = 'Reservations <strong>must</strong> be approved';
        $strings['ResourceRequiresApprovalNone'] = 'Reservations <strong>do not</strong> require approval';
        $strings['ResourcePermissionAutoGranted'] = 'Permission <strong>is</strong> automatically granted to users';
        $strings['ResourcePermissionNotAutoGranted'] = 'Permission <strong>is not</strong> automatically granted to users';
        $strings['ResourceMinNotice'] = 'Reservations must be made at least <strong>%s</strong> prior to start time';
        $strings['ResourceAdvanceNoticeCreate'] = 'notice for new reservations';
        $strings['ResourceMinNoticeNone'] = '<strong>No advance notice</strong> for new reservations';
        $strings['ResourceMinNoticeUpdate'] = 'Reservations must be updated at least <strong>%s</strong> prior to start time';
        $strings['ResourceMinNoticeNoneUpdate'] = '<strong>No advance notice</strong> for reservation updates';
        $strings['ResourceAdvanceNoticeUpdate'] = 'notice for reservation updates';
        $strings['ResourceMinNoticeDelete'] = 'Reservations must be deleted at least <strong>%s</strong> prior to start time';
        $strings['ResourceMinNoticeNoneDelete'] = '<strong>No advance notice</strong> for reservation deletion';
        $strings['ResourceAdvanceNoticeDelete'] = 'notice for reservation deletion';
        $strings['ResourceMaxNoticeEnd'] = 'maximum notice for new reservations';
        $strings['ResourceMaxNotice'] = 'Reservations must not end more than <strong>%s</strong> from the current time';
        $strings['ResourceMaxNoticeNone'] = 'Reservations can end at <strong>any point</strong> in the future';
        $strings['ResourceBufferTime'] = 'There must be <strong>%s</strong> between reservations';
        $strings['BetweenReservationsThereMustBeAtLeast'] = 'Between reservations, there must be at least';
        $strings['ResourceBufferTimeNone'] = 'There is <strong>no buffer</strong> between reservations';
        $strings['ResourceAllowMultiDay'] = 'Reservations <strong>can</strong> be made across days';
        $strings['ResourceNotAllowMultiDay'] = 'Reservations <strong>cannot</strong> be made across days';
        $strings['ResourceCapacity'] = 'This resource has a capacity of <strong>%s</strong> people';
        $strings['ResourceCapacityNone'] = 'This resource has <strong>unlimited</strong> capacity';
        $strings['AddNewResource'] = 'Add New Resource';
        $strings['AddNewUser'] = 'Add New User';
        $strings['AddResource'] = 'Add Resource';
        $strings['Capacity'] = 'Capacity';
        $strings['Access'] = 'Access';
        $strings['Duration'] = 'Duration';
        $strings['Active'] = 'Active';
        $strings['Inactive'] = 'Inactive';
        $strings['ResetPassword'] = 'Reset Password';
        $strings['LastLogin'] = 'Last Login';
        $strings['Search'] = 'Search';
        $strings['ResourcePermissions'] = 'Resource Permissions';
        $strings['Reservations'] = 'Reservations';
        $strings['Groups'] = 'Groups';
        $strings['Users'] = 'Users';
        $strings['AllUsers'] = 'All Users';
        $strings['AllGroups'] = 'All Groups';
        $strings['AllSchedules'] = 'All Schedules';
        $strings['UsernameOrEmail'] = 'Username or Email';
        $strings['Members'] = 'Members';
        $strings['QuickSlotCreationTimes'] = 'Create slots every %s minutes between';
        $strings['ApplyUpdatesTo'] = 'Apply Updates To';
        $strings['CancelParticipation'] = 'Cancel Participation';
        $strings['Attending'] = 'Attending';
        $strings['QuotaConfigurationInterval'] = 'On %s for %s users in %s are limited to %s %s every %s %s';
        $strings['QuotaEnforcement'] = 'Enforced %s %s';
        $strings['reservations'] = 'reservations';
        $strings['reservation'] = 'reservation';
        $strings['ChangeCalendar'] = 'Change Calendar';
        $strings['AddQuota'] = 'Add Quota';
        $strings['FindUser'] = 'Find User';
        $strings['Created'] = 'Created';
        $strings['LastModified'] = 'Last Modified';
        $strings['GroupName'] = 'Group Name';
        $strings['GroupMembers'] = 'Group Members';
        $strings['GroupRoles'] = 'Group Roles';
        $strings['GroupAdmin'] = 'Group Administrator';
        $strings['Actions'] = 'Actions';
        $strings['CurrentPassword'] = 'Current Password';
        $strings['NewPassword'] = 'New Password';
        $strings['InvalidPassword'] = 'Current password is incorrect';
        $strings['PasswordChangedSuccessfully'] = 'Your password has been changed successfully';
        $strings['SignedInAs'] = 'Signed in as';
        $strings['NotSignedIn'] = 'You are not signed in';
        $strings['ReservationTitle'] = 'Title of reservation';
        $strings['ReservationDescription'] = 'Description of reservation';
        $strings['ResourceList'] = 'Resources to be reserved';
        $strings['Accessories'] = 'Accessories';
        $strings['InvitationList'] = 'Invitees';
        $strings['AccessoryName'] = 'Accessory Name';
        $strings['QuantityAvailable'] = 'Quantity Available';
        $strings['Resources'] = 'Resources';
        $strings['Participants'] = 'Participants';
        $strings['User'] = 'User';
        $strings['Resource'] = 'Resource';
        $strings['Status'] = 'Status';
        $strings['Approve'] = 'Approve';
        $strings['Page'] = 'Page';
        $strings['Rows'] = 'Rows';
        $strings['Unlimited'] = 'Unlimited';
        $strings['Email'] = 'Email';
        $strings['EmailAddress'] = 'Email Address';
        $strings['Phone'] = 'Phone';
        $strings['Organization'] = 'Organization';
        $strings['Position'] = 'Position';
        $strings['Language'] = 'Language';
        $strings['Permissions'] = 'Permissions';
        $strings['Reset'] = 'Reset';
        $strings['FindGroup'] = 'Find Group';
        $strings['Manage'] = 'Manage';
        $strings['None'] = 'None';
        $strings['AddToOutlook'] = 'Add to Calendar';
        $strings['Done'] = 'Done';
        $strings['RememberMe'] = 'Remember Me';
        $strings['FirstTimeUser?'] = 'First Time User?';
        $strings['CreateAnAccount'] = 'Create an Account';
        $strings['ViewSchedule'] = 'View Schedule';
        $strings['ForgotMyPassword'] = 'Forgot Password?';
        $strings['YouWillBeEmailedPasswordInstructions'] = 'You will be emailed instructions to update your password';
        $strings['Close'] = 'Close';
        $strings['ExportToCSV'] = 'Export to CSV';
        $strings['OK'] = 'OK';
        $strings['Working'] = 'Working...';
        $strings['Login'] = 'Login';
        $strings['AdditionalInformation'] = 'Additional Information';
        $strings['AllFieldsAreRequired'] = 'all fields are required';
        $strings['Optional'] = 'optional';
        $strings['YourProfileWasUpdated'] = 'Your profile was updated';
        $strings['YourSettingsWereUpdated'] = 'Your settings were updated';
        $strings['Register'] = 'Register';
        $strings['SecurityCode'] = 'Security Code';
        $strings['PreferenceSendEmail'] = 'Send me an email';
        $strings['PreferenceNoEmail'] = 'Do not notify me';
        $strings['ReservationCreated'] = 'Your reservation was successfully created!';
        $strings['ReservationUpdated'] = 'Your reservation was successfully updated!';
        $strings['ReservationRemoved'] = 'Your reservation was removed';
        $strings['ReservationRequiresApproval'] = 'One or more of the resources reserved require approval before usage.  This reservation will be pending until it is approved.';
        $strings['YourReferenceNumber'] = 'Your reference number is %s';
        $strings['ChangeUser'] = 'Change User';
        $strings['MoreResources'] = 'More Resources';
        $strings['ReservationLength'] = 'Reservation Length';
        $strings['ParticipantList'] = 'Participant List';
        $strings['AddParticipants'] = 'Add Participants';
        $strings['InviteOthers'] = 'Invite Others';
        $strings['AddResources'] = 'Add Resources';
        $strings['AddAccessories'] = 'Add Accessories';
        $strings['Accessory'] = 'Accessory';
        $strings['QuantityRequested'] = 'Quantity Requested';
        $strings['CreatingReservation'] = 'Creating Reservation';
        $strings['UpdatingReservation'] = 'Updating Reservation';
        $strings['DeleteWarning'] = 'This action is permanent and cannot be undone!';
        $strings['DeleteAccessoryWarning'] = 'Deleting this accessory will remove it from all reservations.';
        $strings['AddAccessory'] = 'Add Accessory';
        $strings['AddBlackout'] = 'Add Blackout';
        $strings['AllResourcesOn'] = 'All Resources On';
        $strings['Reason'] = 'Reason';
        $strings['BlackoutShowMe'] = 'Show me conflicting reservations';
        $strings['BlackoutDeleteConflicts'] = 'Delete conflicting reservations';
        $strings['Filter'] = 'Filter';
        $strings['Between'] = 'Between';
        $strings['CreatedBy'] = 'Created By';
        $strings['BlackoutCreated'] = 'Blackout Created';
        $strings['BlackoutNotCreated'] = 'Blackout could not be created';
        $strings['BlackoutUpdated'] = 'Blackout Updated';
        $strings['BlackoutNotUpdated'] = 'Blackout could not be updated';
        $strings['BlackoutConflicts'] = 'There are conflicting blackout times';
        $strings['ReservationConflicts'] = 'There are conflicting reservations times';
        $strings['UsersInGroup'] = 'Users in this group';
        $strings['Browse'] = 'Browse';
        $strings['DeleteGroupWarning'] = 'Deleting this group will remove all associated resource permissions.  Users in this group may lose access to resources.';
        $strings['WhatRolesApplyToThisGroup'] = 'Which roles apply to this group?';
        $strings['WhoCanManageThisGroup'] = 'Who can manage this group?';
        $strings['WhoCanManageThisSchedule'] = 'Who can manage this schedule?';
        $strings['AllQuotas'] = 'All Quotas';
        $strings['QuotaReminder'] = 'Remember: Quotas are enforced based on the schedule\'s timezone.';
        $strings['AllReservations'] = 'All Reservations';
        $strings['PendingReservations'] = 'Pending Reservations';
        $strings['Approving'] = 'Approving';
        $strings['MoveToSchedule'] = 'Move to schedule';
        $strings['DeleteResourceWarning'] = 'Deleting this resource will delete all associated data, including';
        $strings['DeleteResourceWarningReservations'] = 'all past, current and future reservations associated with it';
        $strings['DeleteResourceWarningPermissions'] = 'all permission assignments';
        $strings['DeleteResourceWarningReassign'] = 'Please reassign anything that you do not want to be deleted before proceeding';
        $strings['ScheduleLayout'] = 'Layout (all times %s)';
        $strings['ReservableTimeSlots'] = 'Reservable Time Slots';
        $strings['BlockedTimeSlots'] = 'Blocked Time Slots';
        $strings['ThisIsTheDefaultSchedule'] = 'This is the default schedule';
        $strings['DefaultScheduleCannotBeDeleted'] = 'Default schedule cannot be deleted';
        $strings['MakeDefault'] = 'Make Default';
        $strings['BringDown'] = 'Bring Down';
        $strings['ChangeLayout'] = 'Change Layout';
        $strings['AddSchedule'] = 'Add Schedule';
        $strings['StartsOn'] = 'Starts On';
        $strings['NumberOfDaysVisible'] = 'Number of Days Visible';
        $strings['UseSameLayoutAs'] = 'Use Same Layout As';
        $strings['Format'] = 'Format';
        $strings['OptionalLabel'] = 'Optional Label';
        $strings['LayoutInstructions'] = 'Enter one slot per line.  Slots must be provided for all 24 hours of the day beginning and ending at 12:00 AM.';
        $strings['AddUser'] = 'Add User';
        $strings['UserPermissionInfo'] = 'Actual access to resource may be different depending on user role, group permissions, or external permission settings';
        $strings['DeleteUserWarning'] = 'Deleting this user will remove all of their current, future, and historical reservations.';
        $strings['AddAnnouncement'] = 'Add Announcement';
        $strings['Announcement'] = 'Announcement';
        $strings['Priority'] = 'Priority';
        $strings['Reservable'] = 'Open';
        $strings['Unreservable'] = 'Blocked';
        $strings['Reserved'] = 'Reserved';
        $strings['MyReservation'] = 'My Reservation';
        $strings['Pending'] = 'Pending';
        $strings['Past'] = 'Past';
        $strings['Restricted'] = 'Restricted';
        $strings['ViewAll'] = 'View All';
        $strings['MoveResourcesAndReservations'] = 'Move resources and reservations to';
        $strings['TurnOffSubscription'] = 'Hide from public';
        $strings['TurnOnSubscription'] = 'Show to public (RSS, iCalendar, Tablet, Monitor)';
        $strings['SubscribeToCalendar'] = 'Subscribe to this Calendar';
        $strings['SubscriptionsAreDisabled'] = 'The administrator has disabled calendar subscriptions';
        $strings['NoResourceAdministratorLabel'] = '(No Resource Administrator)';
        $strings['WhoCanManageThisResource'] = 'Who Can Manage This Resource?';
        $strings['ResourceAdministrator'] = 'Resource Administrator';
        $strings['Private'] = 'Private';
        $strings['Accept'] = 'Accept';
        $strings['Decline'] = 'Decline';
        $strings['ShowFullWeek'] = 'Show Full Week';
        $strings['CustomAttributes'] = 'Custom Attributes';
        $strings['AddAttribute'] = 'Add Attribute';
        $strings['EditAttribute'] = 'Update Attribute';
        $strings['DisplayLabel'] = 'Display Label';
        $strings['Type'] = 'Type';
        $strings['Required'] = 'Required';
        $strings['ValidationExpression'] = 'Validation Expression';
        $strings['PossibleValues'] = 'Possible Values';
        $strings['SingleLineTextbox'] = 'Single Line Textbox';
        $strings['MultiLineTextbox'] = 'Multiple Line Textbox';
        $strings['Checkbox'] = 'Checkbox';
        $strings['SelectList'] = 'Select List';
        $strings['CommaSeparated'] = 'comma separated';
        $strings['Category'] = 'Category';
        $strings['CategoryReservation'] = 'Reservation';
        $strings['CategoryGroup'] = 'Group';
        $strings['SortOrder'] = 'Sort Order';
        $strings['Title'] = 'Title';
        $strings['AdditionalAttributes'] = 'Additional Attributes';
        $strings['True'] = 'True';
        $strings['False'] = 'False';
        $strings['ResetPasswordEmailSent'] = 'If this email address exists, you will receive an email with instructions to reset your password. This request expires in 30 minutes.';
        $strings['ActivationEmailSent'] = 'You will receive an activation email soon.';
        $strings['AccountActivationError'] = 'Sorry, we could not activate your account.';
        $strings['Attachments'] = 'Attachments';
        $strings['AttachFile'] = 'Attach File';
        $strings['Maximum'] = 'max';
        $strings['NoScheduleAdministratorLabel'] = 'No Schedule Administrator';
        $strings['ScheduleAdministrator'] = 'Schedule Administrator';
        $strings['Total'] = 'Total';
        $strings['QuantityReserved'] = 'Quantity Reserved';
        $strings['AllAccessories'] = 'All Accessories';
        $strings['GetReport'] = 'Get Report';
        $strings['NoResultsFound'] = 'No matching results found';
        $strings['SaveThisReport'] = 'Save This Report';
        $strings['ReportSaved'] = 'Report Saved!';
        $strings['EmailReport'] = 'Email Report';
        $strings['ReportSent'] = 'Report Sent!';
        $strings['RunReport'] = 'Run Report';
        $strings['NoSavedReports'] = 'You have no saved reports.';
        $strings['CurrentWeek'] = 'Current Week';
        $strings['CurrentMonth'] = 'Current Month';
        $strings['AllTime'] = 'All Time';
        $strings['FilterBy'] = 'Filter By';
        $strings['Select'] = 'Select';
        $strings['List'] = 'List';
        $strings['TotalTime'] = 'Time';
        $strings['Count'] = 'Count';
        $strings['Usage'] = 'Usage';
        $strings['AggregateBy'] = 'Aggregate By';
        $strings['Range'] = 'Range';
        $strings['Choose'] = 'Choose';
        $strings['All'] = 'All';
        $strings['ViewAsChart'] = 'View As Chart';
        $strings['ReservedResources'] = 'Reserved Resources';
        $strings['ReservedAccessories'] = 'Reserved Accessories';
        $strings['ResourceUsageTimeBooked'] = 'Resource Usage - Time Booked';
        $strings['ResourceUsageReservationCount'] = 'Resource Usage - Reservation Count';
        $strings['Top20UsersTimeBooked'] = 'Top 20 Users - Time Booked';
        $strings['Top20UsersReservationCount'] = 'Top 20 Users - Reservation Count';
        $strings['ConfigurationUpdated'] = 'The configuration file was updated';
        $strings['ConfigurationUiNotEnabled'] = 'This page cannot be accessed because $conf[\'settings\'][\'pages\'][\'enable.configuration\'] is set to false or missing.';
        $strings['ConfigurationFileNotWritable'] = 'The config file is not writable. Please check the permissions of this file and try again.';
        $strings['ConfigurationUpdateHelp'] = 'Refer to the Configuration section of the <a target=_blank href=%s>Help File</a> for documentation on these settings.';
        $strings['GeneralConfigSettings'] = 'settings';
        $strings['UseSameLayoutForAllDays'] = 'Use the same layout for all days';
        $strings['LayoutVariesByDay'] = 'Layout varies by day';
        $strings['ManageReminders'] = 'Reminders';
        $strings['ReminderUser'] = 'User ID';
        $strings['ReminderMessage'] = 'Message';
        $strings['ReminderAddress'] = 'Addresses';
        $strings['ReminderSendtime'] = 'Time To Send';
        $strings['ReminderRefNumber'] = 'Reservation Reference Number';
        $strings['ReminderSendtimeDate'] = 'Date of Reminder';
        $strings['ReminderSendtimeTime'] = 'Time of Reminder (HH:MM)';
        $strings['ReminderSendtimeAMPM'] = 'AM / PM';
        $strings['AddReminder'] = 'Add Reminder';
        $strings['DeleteReminderWarning'] = 'Are you sure you want to delete this?';
        $strings['NoReminders'] = 'You have no upcoming reminders.';
        $strings['Reminders'] = 'Reminders';
        $strings['SendReminder'] = 'Send Reminder';
        $strings['minutes'] = 'minutes';
        $strings['hours'] = 'hours';
        $strings['days'] = 'days';
        $strings['minute'] = 'minute';
        $strings['hour'] = 'hour';
        $strings['day'] = 'day';
        $strings['ReminderBeforeStart'] = 'before the start time';
        $strings['ReminderBeforeEnd'] = 'before the end time';
        $strings['Logo'] = 'Logo';
        $strings['CssFile'] = 'CSS File';
        $strings['ThemeUploadSuccess'] = 'Your changes have been saved. Refresh the page for changes to take effect.';
        $strings['MakeDefaultSchedule'] = 'Make this my default schedule';
        $strings['DefaultScheduleSet'] = 'This is now your default schedule';
        $strings['FlipSchedule'] = 'Flip the schedule layout';
        $strings['Next'] = 'Next';
        $strings['Success'] = 'Success';
        $strings['Participant'] = 'Participant';
        $strings['ResourceFilter'] = 'Resource Filter';
        $strings['ResourceGroups'] = 'Resource Groups';
        $strings['AddNewGroup'] = 'Add a new group';
        $strings['Quit'] = 'Quit';
        $strings['AddGroup'] = 'Add Group';
        $strings['StandardScheduleDisplay'] = 'Use the standard schedule display';
        $strings['TallScheduleDisplay'] = 'Use the tall schedule display';
        $strings['WideScheduleDisplay'] = 'Use the wide schedule display';
        $strings['CondensedWeekScheduleDisplay'] = 'Use condensed week schedule display';
        $strings['ResourceGroupHelp1'] = 'Drag and drop resource groups to reorganize.';
        $strings['ResourceGroupHelp2'] = 'Right click a resource group name for additional actions.';
        $strings['ResourceGroupHelp3'] = 'Drag and drop resources to add them to groups.';
        $strings['ResourceGroupWarning'] = 'If using resource groups, each resource must be assigned to at least one group. Unassigned resources will not be able to be reserved.';
        $strings['ResourceType'] = 'Resource Type';
        $strings['AppliesTo'] = 'Applies To';
        $strings['UniquePerInstance'] = 'Unique Per Instance';
        $strings['AddResourceType'] = 'Add Resource Type';
        $strings['NoResourceTypeLabel'] = '(no resource type set)';
        $strings['ClearFilter'] = 'Clear Filter';
        $strings['MinimumCapacity'] = 'Minimum Capacity';
        $strings['Color'] = 'Color';
        $strings['Available'] = 'Available';
        $strings['Unavailable'] = 'Unavailable';
        $strings['Hidden'] = 'Hidden';
        $strings['ResourceStatus'] = 'Resource Status';
        $strings['CurrentStatus'] = 'Current Status';
        $strings['AllReservationResources'] = 'All Reservation Resources';
        $strings['File'] = 'File';
        $strings['BulkResourceUpdate'] = 'Bulk Resource Update';
        $strings['Unchanged'] = 'Unchanged';
        $strings['Common'] = 'Common';
        $strings['AdminOnly'] = 'Admin Only';
        $strings['AdvancedFilter'] = 'Advanced Filter';
        $strings['MinimumQuantity'] = 'Minimum Quantity';
        $strings['MaximumQuantity'] = 'Maximum Quantity';
        $strings['ChangeLanguage'] = 'Change Language';
        $strings['AddRule'] = 'Add Rule';
        $strings['Attribute'] = 'Attribute';
        $strings['RequiredValue'] = 'Required Value';
        $strings['ReservationCustomRuleAdd'] = 'Use this color when the reservation attribute is set to the following value';
        $strings['AddReservationColorRule'] = 'Add Reservation Color Rule';
        $strings['LimitAttributeScope'] = 'Collect In Specific Cases';
        $strings['CollectFor'] = 'Collect For';
        $strings['OnlyCollectInCertainCases'] = 'Only Collect In Certain Cases';
        $strings['SignIn'] = 'Sign In';
        $strings['AllParticipants'] = 'All Participants';
        $strings['RegisterANewAccount'] = 'Register a New Account';
        $strings['Dates'] = 'Dates';
        $strings['More'] = 'More';
        $strings['ResourceAvailability'] = 'Resource Availability';
        $strings['UnavailableAllDay'] = 'Unavailable All Day';
        $strings['AvailableUntil'] = 'Available Until';
        $strings['AvailableBeginningAt'] = 'Available Beginning At';
        $strings['AvailableAt'] = 'Available At';
        $strings['AllResourceTypes'] = 'All Resource Types';
        $strings['AllResourceStatuses'] = 'All Resource Statuses';
        $strings['AllowParticipantsToJoin'] = 'Allow Others To Join';
        $strings['Join'] = 'Join';
        $strings['YouAreAParticipant'] = 'You are a participant of this reservation';
        $strings['YouAreInvited'] = 'You are invited to this reservation';
        $strings['YouCanJoinThisReservation'] = 'You can join this reservation';
        $strings['Import'] = 'Import';
        $strings['GetTemplate'] = 'Get Template';
        $strings['UserImportInstructions'] = '<ul><li>File must be in CSV format.</li><li>Username and email are required fields.</li><li>Attribute validity will not be enforced.</li><li>Leaving other fields blank will set default values and \'password\' as the user\'s password.</li><li>Use the supplied template as an example.</li></ul>';
        $strings['RowsImported'] = 'Rows Imported';
        $strings['RowsSkipped'] = 'Rows Skipped';
        $strings['Columns'] = 'Columns';
        $strings['Reserve'] = 'Reserve';
        $strings['AllDay'] = 'All Day';
        $strings['Everyday'] = 'Every Day';
        $strings['IncludingCompletedReservations'] = 'Including Completed Reservations';
        $strings['NotCountingCompletedReservations'] = 'Not Including Completed Reservations';
        $strings['RetrySkipConflicts'] = 'Skip conflicting reservations';
        $strings['Retry'] = 'Retry';
        $strings['RemoveExistingPermissions'] = 'Remove existing permissions?';
        $strings['Continue'] = 'Continue';
        $strings['WeNeedYourEmailAddress'] = 'We need your email address to reserve';
        $strings['ResourceColor'] = 'Resource Color';
        $strings['DateTime'] = 'Date Time';
        $strings['AutoReleaseNotification'] = 'Automatically released if not checked in within <strong>%s</strong> minutes';
        $strings['AutoReleaseDeleteNotification'] = 'Automatically deleted if not checked in within <strong>%s</strong> minutes';
        $strings['AutoReleaseEndNotification'] = 'Automatically ended if not checked in within <strong>%s</strong> minutes';
        $strings['RequiresCheckInNotification'] = '<strong>Requires</strong> check in/out';
        $strings['NoCheckInRequiredNotification'] = '<strong>Does not</strong> require check in/out';
        $strings['RequiresApproval'] = 'Requires Approval';
        $strings['CheckingIn'] = 'Checking In';
        $strings['CheckingOut'] = 'Checking Out';
        $strings['CheckIn'] = 'Check In';
        $strings['CheckOut'] = 'Check Out';
        $strings['ReleasedIn'] = 'Released in';
        $strings['CheckedInSuccess'] = 'You are checked in';
        $strings['CheckedOutSuccess'] = 'You are checked out';
        $strings['CheckInFailed'] = 'You could not be checked in';
        $strings['CheckOutFailed'] = 'You could not be checked out';
        $strings['CheckInTime'] = 'Check In Time';
        $strings['CheckOutTime'] = 'Check Out Time';
        $strings['OriginalEndDate'] = 'Original End';
        $strings['ShowSpecificDates'] = 'Show Specific Dates';
        $strings['Users'] = 'Users';
        $strings['Guest'] = 'Guest';
        $strings['ResourceDisplayPrompt'] = 'Resource to Display';
        $strings['Credits'] = 'Credits';
        $strings['AvailableCredits'] = 'Available Credits';
        $strings['CreditUsagePerSlot'] = 'Requires %s credits per slot (off peak)';
        $strings['PeakCreditUsagePerSlot'] = 'Requires %s credits per slot (peak)';
        $strings['CreditsRule'] = 'You do not have enough credits. Credits required: %s. Credits in account: %s';
        $strings['PeakTimes'] = 'Peak Times';
        $strings['AllYear'] = 'All Year';
        $strings['MoreOptions'] = 'More Options';
        $strings['SendAsEmail'] = 'Send As Email';
        $strings['UsersInGroups'] = 'Users In Groups';
        $strings['UsersWithAccessToResources'] = 'Users With Access To Resources';
        $strings['AnnouncementSubject'] = 'A new announcement was posted by %s';
        $strings['AnnouncementEmailNotice'] = 'users will be sent this announcement as an email';
        $strings['Day'] = 'Day';
        $strings['NotifyWhenAvailable'] = 'Notify Me When Available';
        $strings['AddingToWaitlist'] = 'Adding you to the wait list';
        $strings['WaitlistRequestAdded'] = 'You will be notified if this time becomes available';
        $strings['PrintQRCode'] = 'Print QR Code';
        $strings['FindATime'] = 'Find A Time';
        $strings['AnyResource'] = 'Any Resource';
        $strings['ThisWeek'] = 'This Week';
        $strings['Hours'] = 'Hours';
        $strings['Minutes'] = 'Minutes';
        $strings['ImportICS'] = 'Import From ICS';
        $strings['ImportQuartzy'] = 'Import From Quartzy';
        $strings['OnlyIcs'] = 'Only *.ics files can be uploaded.';
        $strings['IcsLocationsAsResources'] = 'Locations will be imported as resources.';
        $strings['IcsMissingOrganizer'] = 'Any event missing an organizer will have the owner set to the current user.';
        $strings['IcsWarning'] = 'Reservation rules will not be enforced - conflicts, duplicates, etc are possible.';
        $strings['BlackoutAroundConflicts'] = 'Blackout around conflicting reservations';
        $strings['DuplicateReservation'] = 'Duplicate';
        $strings['UnavailableNow'] = 'Unavailable Now';
        $strings['ReserveLater'] = 'Reserve Later';
        $strings['CollectedFor'] = 'Collected For';
        $strings['IncludeDeleted'] = 'Include Deleted Reservations';
        $strings['Deleted'] = 'Deleted';
        $strings['Back'] = 'Back';
        $strings['Forward'] = 'Forward';
        $strings['DateRange'] = 'Date Range';
        $strings['Copy'] = 'Copy';
        $strings['Detect'] = 'Detect';
        $strings['Autofill'] = 'Autofill';
        $strings['NameOrEmail'] = 'name or email';
        $strings['ImportResources'] = 'Import Resources';
        $strings['ExportResources'] = 'Export Resources';
        $strings['ResourceImportInstructions'] = '<ul><li>File must be in CSV format with UTF-8 encoding.</li><li>Status options are Available, Unavailable, or Hidden.</li><li>Color should be specified as the hex value. ex) #ffffff.</li><li>Comma separate multiple resource groups or resource relationships.</li><li>Durations must be specified in the format #d#h#m (1d3h30m for 1 day, 3 hours, 30 minutes).</li><li>Credit Applicability can be either \'per slot\' or \'per reservation\'.</li><li>Release Action options are Delete or End.</li><li>Export the resources or use the template as an example.</li></ul>';
        $strings['ReservationImportInstructions'] = '<ul><li>File must be in CSV format with UTF-8 encoding.</li><li>Email, resource names, begin, and end are required fields.</li><li>Begin and end require full date time. Recommended format is YYYY-mm-dd HH:mm (2017-12-31 20:30).</li><li>Rules, conflicts, and valid time slots will not be checked.</li><li>Notifications will not be sent.</li><li>Attribute validity will not be enforced.</li><li>Comma separate multiple resource names.</li><li>Use the supplied template as an example.</li></ul>';
        $strings['AutoReleaseMinutes'] = 'Autorelease Minutes';
        $strings['CreditsPeak'] = 'Credits (peak)';
        $strings['CreditsOffPeak'] = 'Credits (off peak)';
        $strings['ResourceMinLengthCsv'] = 'Reservation Minimum Length';
        $strings['ResourceMaxLengthCsv'] = 'Reservation Maximum Length';
        $strings['ResourceBufferTimeCsv'] = 'Buffer Time';
        $strings['ResourceMinNoticeAddCsv'] = 'Reservation Add Minimum Notice';
        $strings['ResourceMinNoticeUpdateCsv'] = 'Reservation Update Minimum Notice';
        $strings['ResourceMinNoticeDeleteCsv'] = 'Reservation Delete Minimum Notice';
        $strings['ResourceMaxNoticeCsv'] = 'Reservation Maximum End';
        $strings['Export'] = 'Export';
        $strings['DeleteMultipleUserWarning'] = 'Deleting these users will remove all of their current, future, and historical reservations. No emails will be sent.';
        $strings['DeleteMultipleReservationsWarning'] = 'No emails will be sent.';
        $strings['ErrorMovingReservation'] = 'Error Moving Reservation';
        $strings['SelectUser'] = 'Select User';
        $strings['InviteUsers'] = 'Invite Users';
        $strings['InviteUsersLabel'] = 'Enter the email addresses of the people to invite (one per line)';
        $strings['ApplyToCurrentUsers'] = 'Apply to current users';
        $strings['ReasonText'] = 'Reason text';
        $strings['NoAvailableMatchingTimes'] = 'There are no available times that match your search';
        $strings['Schedules'] = 'Schedules';
        $strings['NotifyUser'] = 'Notify User';
        $strings['UpdateUsersOnImport'] = 'Update existing user if email already exists';
        $strings['UpdateResourcesOnImport'] = 'Update existing resources if name already exists';
        $strings['Reject'] = 'Reject';
        $strings['CheckingAvailability'] = 'Checking availability';
        $strings['CreditPurchaseNotEnabled'] = 'You have not enabled the ability to purchase credits';
        $strings['CreditsCost'] = 'Each credit costs';
        $strings['Currency'] = 'Currency';
        $strings['PayPalClientId'] = 'Client ID';
        $strings['PayPalSecret'] = 'Secret';
        $strings['PayPalEnvironment'] = 'Environment';
        $strings['Sandbox'] = 'Sandbox';
        $strings['Live'] = 'Live';
        $strings['StripePublishableKey'] = 'Publishable key';
        $strings['StripeSecretKey'] = 'Secret key';
        $strings['CreditsUpdated'] = 'Credit cost has been updated';
        $strings['GatewaysUpdated'] = 'Payment gateways have been updated';
        $strings['PurchaseSummary'] = 'Purchase Summary';
        $strings['EachCreditCosts'] = 'Each credit costs';
        $strings['Checkout'] = 'Checkout';
        $strings['Quantity'] = 'Quantity';
        $strings['CreditPurchase'] = 'Credit Purchase';
        $strings['EmptyCart'] = 'Your cart is empty.';
        $strings['BuyCredits'] = 'Buy Credits';
        $strings['CreditsPurchased'] = 'credits purchased.';
        $strings['ViewYourCredits'] = 'View your credits';
        $strings['TryAgain'] = 'Try Again';
        $strings['PurchaseFailed'] = 'We had trouble processing your payment.';
        $strings['NoteCreditsPurchased'] = 'Credits purchased';
        $strings['CreditsUpdatedLog'] = 'Credits updated by %s';
        $strings['ReservationCreatedLog'] = 'Reservation created. Reference number %s';
        $strings['ReservationUpdatedLog'] = 'Reservation updated. Reference number %s';
        $strings['ReservationDeletedLog'] = 'Reservation deleted. Reference number %s';
        $strings['BuyMoreCredits'] = 'Buy More Credits';
        $strings['Transactions'] = 'Transactions';
        $strings['Cost'] = 'Cost';
        $strings['PaymentGateways'] = 'Payment Gateways';
        $strings['CreditHistory'] = 'Credit History';
        $strings['TransactionHistory'] = 'Transaction History';
        $strings['Date'] = 'Date';
        $strings['Note'] = 'Note';
        $strings['CreditsBefore'] = 'Credits Before';
        $strings['CreditsAfter'] = 'Credits After';
        $strings['TransactionFee'] = 'Transaction Fee';
        $strings['InvoiceNumber'] = 'Invoice Number';
        $strings['TransactionId'] = 'Transaction ID';
        $strings['Gateway'] = 'Gateway';
        $strings['GatewayTransactionDate'] = 'Gateway Transaction Date';
        $strings['Refund'] = 'Refund';
        $strings['IssueRefund'] = 'Issue Refund';
        $strings['RefundIssued'] = 'Refund Issued Successfully';
        $strings['RefundAmount'] = 'Refund Amount';
        $strings['AmountRefunded'] = 'Refunded';
        $strings['FullyRefunded'] = 'Fully Refunded';
        $strings['YourCredits'] = 'Your Credits';
        $strings['PayWithCard'] = 'Pay with Card';
        $strings['or'] = 'or';
        $strings['CreditsRequired'] = 'Credits Required';
        $strings['AddToGoogleCalendar'] = 'Add to Google';
        $strings['Image'] = 'Image';
        $strings['ChooseOrDropFile'] = 'Choose a file or drag it here';
        $strings['SlackBookResource'] = 'Book %s now';
        $strings['SlackBookNow'] = 'Book Now';
        $strings['SlackNotFound'] = 'We could not find a resource with that name. Book Now to start a new reservation.';
        $strings['AutomaticallyAddToGroup'] = 'Automatically add new users to this group';
        $strings['GroupAutomaticallyAdd'] = 'Auto Add';
        $strings['TermsOfService'] = 'Terms of Service';
        $strings['EnterTermsManually'] = 'Enter Terms Manually';
        $strings['LinkToTerms'] = 'Link to Terms';
        $strings['UploadTerms'] = 'Upload Terms';
        $strings['RequireTermsOfServiceAcknowledgement'] = 'Require Terms of Service Acknowledgement';
        $strings['UponReservation'] = 'Upon Reservation';
        $strings['UponRegistration'] = 'Upon Registration';
        $strings['ViewTerms'] = 'View Terms of Service';
        $strings['IAccept'] = 'I Accept';
        $strings['TheTermsOfService'] = 'the Terms of Service';
        $strings['DisplayPage'] = 'Display Page';
        $strings['AvailableAllYear'] = 'All Year';
        $strings['Availability'] = 'Availability';
        $strings['AvailableBetween'] = 'Available Between';
        $strings['ConcurrentYes'] = 'Resources can be booked by more than one person at a time';
        $strings['ConcurrentNo'] = 'Resources cannot be booked by more than one person at a time';
        $strings['ScheduleAvailabilityEarly'] = ' This schedule is not yet available. It is available';
        $strings['ScheduleAvailabilityLate'] = 'This schedule is no longer available. It was available';
        $strings['ResourceImages'] = 'Resource Images';
        $strings['FullAccess'] = 'Full Access';
        $strings['ViewOnly'] = 'View Only';
        $strings['Purge'] = 'Purge';
        $strings['UsersWillBeDeleted'] = 'users will be deleted';
        $strings['BlackoutsWillBeDeleted'] = 'blackout times will be deleted';
        $strings['ReservationsWillBePurged'] = 'reservations will be purged';
        $strings['ReservationsWillBeDeleted'] = 'reservations will be deleted';
        $strings['PermanentlyDeleteUsers'] = 'Permanently delete users who have not logged in since';
        $strings['DeleteBlackoutsBefore'] = 'Delete blackout times before';
        $strings['DeletedReservations'] = 'Deleted Reservations';
        $strings['DeleteReservationsBefore'] = 'Delete reservations before';
        $strings['SwitchToACustomLayout'] = 'Switch to appointment slots';
        $strings['SwitchToAStandardLayout'] = 'Switch to fixed layout slots';
        $strings['ThisScheduleUsesACustomLayout'] = 'This schedule uses appointment slots';
        $strings['ThisScheduleUsesAStandardLayout'] = 'This schedule uses fixed layout slots';
        $strings['SwitchLayoutWarning'] = 'Are you sure that you want to change the layout type? This will remove all existing slots.';
        $strings['DeleteThisTimeSlot'] = 'Delete this time slot?';
        $strings['Refresh'] = 'Refresh';
        $strings['ViewReservation'] = 'View Reservation';
        $strings['PublicId'] = 'Public Id';
        $strings['Public'] = 'Public';
        $strings['AtomFeedTitle'] = '%s Reservations';
        $strings['DefaultStyle'] = 'Default Style';
        $strings['Standard'] = 'Standard';
        $strings['StandardView'] = 'Standard View';
        $strings['WideView'] = 'Wide View';
        $strings['TallView'] = 'Tall View';
        $strings['WeekView'] = 'Week View';
        $strings['EmailTemplate'] = 'Email Template';
        $strings['SelectEmailTemplate'] = 'Select Email Template';
        $strings['ReloadOriginalContents'] = 'Reload Original Contents';
        $strings['UpdateEmailTemplateSuccess'] = 'Updated email template';
        $strings['UpdateEmailTemplateFailure'] = 'Could not update email template. Check to make sure the directory is writable.';
        $strings['BulkResourceDelete'] = 'Bulk Resource Delete';
        $strings['NewVersion'] = 'New version!';
        $strings['WhatsNew'] = 'Whats New?';
        $strings['OnlyViewedCalendar'] = 'This schedule can only be viewed from the calendar view';
        $strings['Grid'] = 'Grid';
        $strings['List'] = 'List';
        $strings['NoReservationsFound'] = 'No Reservations Found';
        $strings['EmailReservation'] = 'Email Reservation';
        $strings['AdHocMeeting'] = 'Ad hoc Meeting';
        $strings['NextReservation'] = 'Next Reservation';
        $strings['MissedCheckin'] = 'Missed Checkin';
        $strings['MissedCheckout'] = 'Missed Checkout';
        $strings['Utilization'] = 'Utilization';
        $strings['SpecificTime'] = 'Specific Time';
        $strings['NotAttending'] = 'Not Attending';
        $strings['ViewAvailability'] = 'View Availability';
        $strings['ReservationDetails'] = 'Reservation Details';
        $strings['StartTime'] = 'Start Time';
        $strings['EndTime'] = 'End Time';
        $strings['New'] = 'New';
        $strings['Updated'] = 'Updated';
        $strings['Custom'] = 'Custom';
        $strings['AddDate'] = 'Add Date';
        $strings['RepeatOn'] = 'Repeat On';
        $strings['ScheduleConcurrentMaximum'] = 'A total of <b>%s</b> resources may be reserved concurrently';
        $strings['ScheduleConcurrentMaximumNone'] = 'There is no limit to the number of concurrent reserved resources';
        $strings['ScheduleMaximumConcurrent'] = 'Maximum number of resources reserved concurrently';
        $strings['ScheduleMaximumConcurrentNote'] = 'When set, the total number of resources that can be reserved concurrently for this schedule will be limited.';
        $strings['ScheduleResourcesPerReservationMaximum'] = 'Each reservation is limited to a maximum of <b>%s</b> resources';
        $strings['ScheduleResourcesPerReservationNone'] = 'There is no limit to the number of resources per reservation';
        $strings['ScheduleResourcesPerReservation'] = 'Maximum number of resources per reservation';
        $strings['ResourceConcurrentReservations'] = 'Allow %s concurrent reservations';
        $strings['AllowConcurrentReservations'] = 'Allow %s concurrent reservations';
        $strings['ResourceConcurrentReservationsNone'] = '<strong>Do not allow</strong> concurrent reservations';
        $strings['AllowConcurrentReservationsLabel'] = '<strong>Allow</strong> concurrent reservations';
        $strings['ResourceDisplayInstructions'] = 'No resource has been selected. You can find the URL to display a resource in Application Management, Resources. The resource must be publicly accessible.';
        $strings['Owner'] = 'Owner';
        $strings['MaximumConcurrentReservations'] = 'Maximum Concurrent Reservations';
        $strings['NotifyUsers'] = 'Notify Users';
        $strings['Message'] = 'Message';
        $strings['AllUsersWhoHaveAReservationInTheNext'] = 'Anyone with a reservation in the next';
        $strings['ChangeResourceStatus'] = 'Change Resource Status';
        $strings['UpdateGroupsOnImport'] = 'Update existing group if name matches';
        $strings['GroupsImportInstructions'] = '<ul><li>File must be in CSV format.</li><li>Name is required.</li><li>Member lists should be comma separated lists of emails.</li><li>Empty member lists when updating groups will leave members unchanged.</li><li>Permissions lists should be comma separated lists of resource names.</li><li>Empty permissions lists when updating groups will leave permissions unchanged.</li><li>Use the supplied template as an example.</li></ul>';
        $strings['PhoneRequired'] = 'Phone is required';
        $strings['OrganizationRequired'] = 'Organization is required';
        $strings['PositionRequired'] = 'Position is required';
        $strings['GroupMembership'] = 'Group Membership';
        $strings['AvailableGroups'] = 'Available Groups';
        $strings['CheckingAvailabilityError'] = 'Cannot get resource availability - too many resources';
        $strings['ApiOnly'] = 'API Access Only';
        $strings['ApiOnlyDetails'] = 'This user will only be able to log in through the API';
        $strings['PerReservation'] = 'per reservation';
        $strings['PerSlot'] = 'per slot';
        $strings['CreditsCalculated'] = 'Credits calculated';
        $strings['CreditsApplied'] = 'Credit Applicability';
        $strings['CreditsChargedBlockedSlots'] = 'Credits are charged for blocked slots';
        $strings['AllowReservationsToEndInBlockedSlots'] = 'Allow reservations to end in blocked slots';
        $strings['ReservationsMustEndInAvailableSlots'] = 'Reservations must end in available slots';
        $strings['Currently'] = 'Currently';
        $strings['ResourceDisplay'] = 'Resource Display';
        $strings['CopyToClipboard'] = 'Copy to clipboard';
        $strings['CopyEmbedCode'] = 'Copy embed code to clipboard';
        $strings['CopyRssLink'] = 'Copy RSS link to clipboard';
        $strings['CopyICalLink'] = 'Copy iCalendar link to clipboard';
        $strings['CopyToResourceDisplay'] = 'Copy Resource Display link to clipboard';
        $strings['CopiedToClipboard'] = 'Copied to clipboard';
        $strings['UseDefaultLabel'] = 'Use default label';
        $strings['SlotLabel'] = 'Slot Label';
        $strings['ResourceRelationships'] = 'Relationships';
        $strings['MustBeBookedWith'] = 'Must Be Booked With (Two Way)';
        $strings['CannotBeBookedWith'] = 'Cannot Be Booked With';
        $strings['CannotBeBookedAtSameTime'] = 'Cannot Be Booked at the Same Time';
        $strings['UpdateAndSend'] = 'Update and Notify';
        $strings['ResourceImageInstructions'] = 'Up to 10 images are allowed (%sMB each). jpg, gif, png, svg only. Drag to reorder.';
        $strings['ViewFullSizeImage'] = 'View Full Size Image';
        $strings['Default'] = 'Default';
        $strings['DisplayInformation'] = 'Display Information';
        $strings['ResourceInformation'] = 'Resource Information';
        $strings['CopyId'] = 'Copy ID to clipboard';
        $strings['PublicAccess'] = 'Public Access';
        $strings['AllowPublicAccess'] = 'Allow Public Access';
        $strings['AddAllUsers'] = 'Add all users';
        $strings['ChangeAllAccess'] = 'Change all users';
        $strings['ChangeAllGroupAccess'] = 'Change all groups';
        $strings['Reserve'] = 'Reserve';
        $strings['View'] = 'View';
        $strings['NoUsersHavePermission'] = 'No Users Have Permission';
        $strings['RemoveAllPermissions'] = 'Remove All Permissions';
        $strings['RemovePermissions'] = 'Remove Permissions';
        $strings['InheritPermissions'] = 'Remove and Inherit Permissions';
        $strings['ChangeUserAndGroupPermissions'] = 'Change User and Group Permissions';
        $strings['DateFilter'] = 'Date Filter';
        $strings['Equals'] = 'Equals';
        $strings['GreaterThan'] = 'Greater Than';
        $strings['LessThan'] = 'Less Than';
        $strings['HasNoValue'] = 'Has No Value';
        $strings['NoResourcesInstructions'] = "You do not have any resources. Click Add Resource above to add a new resource.<br/><br/>You can learn more about resources in Booked <a href='{{resourceLink}}'>here</a>.<br/><br/>New to Booked? Read our <a href='{{gettingStartedLink}}'>Getting Started Guide</a>";
        $strings['AddMoreResources'] = 'Add More Resources';
        $strings['AddMoreResourcesInfo'] = 'Remain on this page after adding a resource';
        $strings['ResourceNameRequired'] = 'Resource name is required.';
        $strings['ResourceSuccessfullyAdded'] = '{{resourceName}} was added.';
        $strings['ViewAsList'] = 'View As List';
        $strings['ViewDetails'] = 'View Details';
        $strings['DeleteItemModalTitle'] = 'Delete {{itemName}}?';
        $strings['Expand'] = 'Expand';
        $strings['Collapse'] = 'Collapse';
        $strings['DeleteMultiple'] = 'Delete Multiple';
        $strings['DeleteMultipleModalTitle'] = 'Delete Multiple ({{count}})?';
        $strings['DeleteMultipleResourcesWarning'] = 'This will permanently delete all resources that match your current filter, including';
        $strings['ExportAllResources'] = 'Export All Resources';
        $strings['ExportFilteredResources'] = 'Export Filtered Resources';
        $strings['ExportResourceInstructions'] = 'Download a CSV file containing resource information. The exported data can be re-imported for bulk changes.';
        $strings['ImportResourcesConfirm'] = 'Import {{count}} Resources';
        $strings['NoResourceGroups'] = 'There are no resource groups';
        $strings['ShareCalendar'] = 'Share Calendar';
        $strings['DoNotShareCalendar'] = 'Do Not Share Calendar';
        $strings['BackToMainCalendar'] = 'Back to main calendar';
        $strings['ReservationsFound'] = '%s Reservations Found';
        $strings['DeleteAll'] = 'Delete All';
        $strings['CopyResource'] = 'Copy Resource';
        $strings['TermsAcceptedOn'] = 'accepted on {{acceptDate}}';
        $strings['SpecificDates'] = 'Specific Dates';
        $strings['DateOfMonth'] = 'Date of Month';
        $strings['WeekOfMonth'] = 'Week of Month';
        $strings['Rules'] = 'Rules';
        $strings['ReservationMustBeBookedTogether'] = 'These resources must be booked together';
        $strings['ReservationRequiredResourceNoPermission'] = 'You do not have permission to some of the required resources';
        $strings['AddRequiredResources'] = 'Add Required Resources';
        $strings['Rules'] = 'Rules';
        $strings['NoUpcomingReservations'] = 'No upcoming reservations';
        $strings['AddNewMonitorView'] = 'Add Monitor View';
        $strings['UpdateMonitorView'] = 'Update Monitor View';
        $strings['DeleteMonitorView'] = 'Delete Monitor View';
        $strings['DeleteMonitorViewPrompt'] = 'Are you sure you want to delete <strong>{{viewName}}</strong>?';
        $strings['ReservationsToShow'] = 'Reservations to Show';
        $strings['AllUpcomingReservations'] = 'All upcoming reservations';
        $strings['ASetNumberOfUpcomingReservations'] = 'A set number of upcoming reservations';
        $strings['AllReservationsWithinADateRange'] = 'All reservations within a date range';
        $strings['ASpecificSetOfReservations'] = 'A specific set of reservations';
        $strings['UpcomingDaysToShow'] = 'Upcoming Days to Show';
        $strings['UpcomingReservationsToShow'] = 'Upcoming Reservations to Show';
        $strings['DisplayOptions'] = 'Display Options';
        $strings['Style'] = 'Style';
        $strings['ScrollInterval'] = 'Scroll Interval (seconds)';
        $strings['ShowReservations'] = 'Show Reservations';
        $strings['ShowLogo'] = 'Show Logo';
        $strings['ShowDateAndTime'] = 'Show Date and Time';
        $strings['HideAvailability'] = 'Hide Availability';
        $strings['Invited'] = 'Invited';
        $strings['SelectUserOrAddGuest'] = 'Select user or add guest by email';
        $strings['ReservationUploadInstructions'] = 'Upload files of type %s up to %s';
        $strings['UploadFiles'] = 'Drag files here or click to choose files to upload';
        $strings['RetryReservationNotice'] = 'You can retry this reservation, skipping dates with conflicts.';
        $strings['JoinWaitlistReservationNotice'] = 'You can join a waitlist to be notified if this time becomes available.';
        $strings['NewReservation'] = 'New Reservation';
        $strings['ChangeReservation'] = 'Change Reservation';
        $strings['UpdateRecurringTitle'] = 'Update Reservation';
        $strings['ParticipantRecurringNotice'] = 'This reservation is part of a recurring series.';
        $strings['UpdateRecurringNotice'] = 'This reservation is part of a recurring series. Which instances of the series would you like to update?';
        $strings['DeleteReservationModalTitle'] = 'Delete Reservation';
        $strings['DeleteRecurringNotice'] = 'This reservation is part of a recurring series. Which instances of the series would you like to delete?';
        $strings['RequiresApprovalNotice'] = 'This reservation requires your approval.';
        $strings['AcceptInvitation'] = 'Accept Invitation';
        $strings['DeclineInvitation'] = 'Decline Invitation';
        $strings['YouAreAlreadyParticipating'] = 'You are already participating in this reservation';
        $strings['JoinAsGuestNotice'] = 'To join this reservation as a guest, you must provide your email address';
        $strings['CancelThisInstance'] = 'Cancel This Instance';
        $strings['CancelSeries'] = 'Cancel Series';
        $strings['DeclineThisInstance'] = 'Decline This Instance';
        $strings['DeclineSeries'] = 'Decline Series';
        $strings['AcceptThisInstance'] = 'Accept This Instance';
        $strings['AcceptSeries'] = 'Accept Series';
        $strings['JoinThisInstance'] = 'Join This Instance';
        $strings['JoinSeries'] = 'Join Series';
        $strings['MultipleEmailInstructions'] = 'You can add multiple email addresses, separated by a space or comma';
        $strings['SendReservationAsEmail'] = 'Send Email ({{count}})';
        $strings['WithSpecificAttributeValues'] = 'With specific attribute values';
        $strings['ReferenceNumbers'] = 'Reference Numbers';
        $strings['Value'] = 'Value';
        $strings['Ascending'] = 'Ascending';
        $strings['Descending'] = 'Descending';
        $strings['SortDirection'] = 'Direction';
        $strings['SortBy'] = 'Sort By';
        $strings['LoadingCreditHistory'] = 'Loading credit history';
        $strings['HeadingText'] = 'Heading Text';
        $strings['StartTimeIsInPast'] = 'The start time is in the past';
        $strings['GroupCredits'] = 'Credits';
        $strings['Replenish'] = 'Replenish';
        $strings['AddCredits'] = 'Add Credits';
        $strings['ReplenishCredits'] = 'Replenish Credits';
        $strings['AddCreditsEveryDays'] = 'Add %s credits every %s days';
        $strings['AddCreditsDayOfMonth'] = 'Add %s credits on day %s of each month';
        $strings['AutomaticallyAddCredits'] = 'Automatically add credits for all users in this group';
        $strings['AddCreditsToGroup'] = 'Add credits to all users in this group';
        $strings['AddNumberCreditsToGroup'] = 'Add %s credits to all users in this group';
        $strings['CreditsAddedByAdminNote'] = 'Credits added by admin';
        $strings['AutoReplenishCreditsNote'] = 'Credits automatically replenished';
        $strings['Never'] = 'Never';
        $strings['LastReplenished'] = 'Last Replenished';
        $strings['ReservationsAutomaticallyExtended'] = 'Reservations are automatically extended if owner does not check out';
        $strings['ReservationsNotAutomaticallyExtended'] = 'Reservations end if owner does not check out';
        $strings['PasswordResetForced'] = 'You must update your password';
        $strings['ForceChangePassword'] = 'Force the user to change their password next time they log in';
        $strings['NotifyUserPasswordChange'] = 'Send the user an email with the new password';
        $strings['NoScheduleAdminGroupsDefined'] = 'No schedule administrator groups defined';
        $strings['SecurityCheck'] = 'Security Check';
        $strings['SecurityCheckInstructions'] = 'For your security, we need to confirm your account. Please enter the one time passcode sent to %s';
        $strings['OneTimePassCode'] = 'One Time Passcode';
        $strings['ConfirmOTP'] = 'Confirm Passcode';
        $strings['ResendCode'] = 'Send New Passcode';
        $strings['InvalidOtp'] = 'The passcode is incorrect or has expired. Please try again or request a new one time passcode.';
        $strings['OtpResendMessage'] = 'We have sent you a new one time passcode. This code expires in 10 minutes.';
        $strings['ResetPasswordInstructions'] = 'Please provide a new password';
        $strings['ResendResetPassword'] = 'Resend Reset Link';
        $strings['ResetPasswordError'] = 'Invalid password reset link. Password reset links are only valid for %s minutes.';
        $strings['SendResetLink'] = 'Send Reset Link';
        $strings['ConfirmResetPassword'] = 'Your password has been updated. Please log in using your new password.';
        $strings['TransferReservationOwnership'] = 'Transfer Ownership';
        $strings['TransferTo'] = 'Transfer ownership to';
        $strings['FutureReservations'] = 'Future Reservations';
        $strings['TransferOwnershipDeleteWarning'] = 'You can transfer reservation ownership to retain these reservations.';
        $strings['TransferReservationOwnershipNote'] = 'Transfer reservation ownership to a different person.';
        $strings['AddFavoriteResource'] = 'Add Favorite Resource';
        $strings['RemoveFavoriteResource'] = 'Remove Favorite Resource';
        $strings['ReservationsCheckinLimitedToAdmin'] = 'Only admins can check in/out';
        $strings['ReservationDeleted'] = 'Your reservation was deleted';
        $strings['PermissionLevel'] = 'Level';
        $strings['Inherit'] = 'Inherit';
        $strings['NoGroupsHavePermission'] = 'No Groups Have Permission';
        $strings['AddAllGroups'] = 'Add All Groups';
        $strings['NoColor'] = 'No Color';
        $strings['UseDefault'] = 'Use Default';
        $strings['MobileView'] = 'Mobile View';
        $strings['BetweenAnyTimes'] = 'Between Any Times';
        $strings['DeletingReservation'] = 'Deleting Reservation';
        $strings['ResourceAdminRequired'] = 'Resource Administrator is required.';
        $strings['ResourceTypes'] = 'Resource Types';
        $strings['Enabled'] = 'Enabled';
        $strings['CheckAvailability'] = 'Check Availability';
        $strings['ManageAvailableAppointments'] = 'Manage Available Appointments';
        $strings['AddAvailableAppointmentTime'] = 'Add Available Appointment Time';
        $strings['OnlyApplicableAccessories'] = 'Only show accessories that can be booked with my selected resources';
        $strings['SelectThisAppointment'] = 'Select this appointment time';
        $strings['AppointmentTime'] = 'Appointment Time';
        $strings['NoAvailableAppointments'] = 'There are no available appointments for your selected date. Please choose another date.';
        $strings['NoAppointmentsOnDay'] = 'No Appointments';
        $strings['BackDays'] = 'Last %s days';
        $strings['ForwardDays'] = 'Next %s days';
        $strings['LastWeek'] = 'Last Week';
        $strings['ShowMultiResourceGrouped'] = 'Show multi-resource reservations as single event';
        $strings['MinimumParticipants'] = 'Minimum Participants';
        $strings['NoMinimum'] = 'No Minimum';
        $strings['PrintReservations'] = 'Print Reservations';
        $strings['Time'] = 'Time';
        $strings['YourAccountWasCreatedOn'] = 'Your account was created on %s';
        $strings['MissedCheckinTimeWarning'] = 'This reservation missed the checkin time';
        $strings['MissedCheckoutTimeWarning'] = 'This reservation missed the checkout time';
        $strings['CheckedIn'] = 'Checked In';
        $strings['CheckedOut'] = 'Checked Out';
        $strings['SelectUserOrGroup'] = 'Select user or group';
        $strings['NoGroupsAssigned'] = '- No Groups Assigned -';
        $strings['CurrentlyFilteredResources'] = 'Currently Filtered Resources (%s)';
        $strings['AllResourcesWithCount'] = 'All Resources (%s)';
        $strings['Section'] = 'Section';
        $strings['BulkUpdateWarning'] = 'It is recommended to export a backup of your resources before applying a bulk update';
        $strings['DuplicateResourceImportWarning'] = 'We found duplicate resource names. If you want to update the existing resources, please check the update box below.';
        $strings['EventsPerPage'] = 'Events per page';
        $strings['ScheduleReport'] = 'Schedule Delivery';
        $strings['ChangeSchedule'] = 'Change Schedule';
        $strings['Frequency'] = 'Frequency';
        $strings['SendTo'] = 'Send To';
        $strings['ScheduleReportOnThe'] = 'On the';
        $strings['ScheduleReportDayOfTheMonth'] = 'day of the month';
        $strings['AtLeastOneDayMustBeSelected'] = 'At least one day must be selected';
        $strings['AtLeastOneEmailMustBeAdded'] = 'At least one email must be added';
        $strings['LastSent'] = 'Last Sent';
        $strings['ReservationColor'] = 'Reservation Color';
        $strings['PhoneCountry'] = 'Phone Country';
        $strings['SmsDisabled'] = 'SMS Notifications are not enabled.';
        $strings['PreferenceReservationReminders'] = 'Reservation Reminders';
        $strings['PreferenceReservationCreated'] = 'Reservation Created';
        $strings['PreferenceReservationUpdated'] = 'Reservation Updated';
        $strings['PreferenceReservationDeleted'] = 'Reservation Deleted';
        $strings['PreferenceReservationApproved'] = 'Reservation Approved';
        $strings['PreferenceReservationParticipants'] = 'Reservation Participants';
        $strings['PreferenceReservationSeriesEnding'] = 'Reservation Series Ending';
        $strings['PreferenceReservationMissedCheckin'] = 'Missed Reservation Check In';
        $strings['PreferenceReservationMissedCheckout'] = 'Missed Reservation Check Out';
        $strings['ReservationRemindersPreferenceDescription'] = 'Reservation start and end reminders. If enabled, reminders will always be sent via email.';
        $strings['ReservationCreatedPreferenceDescription'] = 'When you create a reservation or someone creates a reservation on your behalf.';
        $strings['ReservationUpdatedPreferenceDescription'] = 'When you update a reservation or someone updates a reservation on your behalf.';
        $strings['ReservationDeletedPreferenceDescription'] = 'When you delete a reservation or someone deletes a reservation on your behalf.';
        $strings['ReservationApprovedPreferenceDescription'] = 'When your pending reservation request has been approved.';
        $strings['ReservationParticipantsPreferenceDescription'] = 'When someone accepts an invitation or cancels their participation on your reservation.';
        $strings['ReservationSeriesEndingPreferenceDescription'] = 'When the last event in a recurring reservation is approaching.';
        $strings['ReservationMissedCheckinPreferenceDescription'] = 'When you have not checked in for a reservation that has started.';
        $strings['ReservationMissedCheckoutPreferenceDescription'] = 'When you have not checked out of a reservation that has ended.';
        $strings['NotificationPreferenceOnlyEmail'] = 'This notification is only available via email.';
        $strings['SMSNotifications'] = 'SMS Notifications';
        $strings['SMSPhoneMissing'] = 'In order to receive SMS messages, please provide your phone number.';
        $strings['UpdateYourProfile'] = 'Update your profile';
        $strings['SMSConfirmCode'] = 'Please enter the passcode that we sent to your phone number (%s)';
        $strings['SMSUpdateYourPhone'] = 'Update your phone number';
        $strings['SMSNeedToConfirm'] = 'We need to confirm your phone number before we can send you SMS messages.';
        $strings['SendConfirmationCode'] = 'Send me a passcode';
        $strings['SMSUnavailableCountry'] = 'We are not able to send SMS messages to your country.';
        $strings['SMSOptInConfirmation'] = 'You have opted into SMS notifications. Any enabled notifications will be sent to';
        $strings['SmsMoreInfo'] = 'Learn more about about setting up SMS for Booked.';
        $strings['SMSAllowedMessagesPerMonth'] = 'Allowed messages per month';
        $strings['SMSSentThisMonth'] = 'Sent this month';
        $strings['SMSRemainingThisMonth'] = 'Remaining this month';
        $strings['SMSAdjustSettingContact'] = 'To adjust your SMS settings, contact';
        $strings['Options'] = 'Options';
        $strings['Calendar'] = 'Calendar';
        $strings['PartialMatch'] = 'Partial Match';
        $strings['UpdateThisReport'] = 'Update This Report';
        $strings['CancelNotification'] = 'Cancel Notification';
        $strings['WaitlistSingle'] = 'There is someone waiting for this time slot';
        $strings['WaitlistPlural'] = 'There are %s others waiting for this time slot';
        $strings['Waitlist'] = 'Waitlist';
        $strings['WaitlistRequests'] = 'Waitlist Requests';
        $strings['AddMeetingLink'] = 'Add Meeting Link';
        $strings['RemoveMeetingLink'] = 'Remove Meeting Link';
        $strings['OpenLink'] = 'Open Link';
        $strings['MeetingLink'] = 'Meeting Link';
        $strings['ZoomMeetingsOwnerOnly'] = 'Zoom meetings can only be created by the reservation owner.';
        $strings['ZoomMeetingsOwnerOnlyUpdate'] = 'Updates to Zoom meetings can only be made by the reservation owner.';
        $strings['ZoomMeetingWillBeCreated'] = 'A Zoom meeting will be created';
        $strings['MustLinkZoomAccount'] = 'You must link your Zoom account.';
        $strings['ZoomDoesNotSupportCustomRecurrence'] = 'Zoom does not support custom recurrence. A meeting will only be created for the first reservation date.';
        $strings['TeamsMeetingsOwnerOnly'] = 'Teams meetings can only be created by the reservation owner.';
        $strings['TeamsMeetingsOwnerOnlyUpdate'] = 'Updates to Teams meetings can only be made by the reservation owner.';
        $strings['TeamsMeetingWillBeCreated'] = 'A Teams meeting will be created';
        $strings['MustLinkTeamsAccount'] = 'You must link your Microsoft account.';
        $strings['TeamsDoesNotSupportCustomRecurrence'] = 'Teams does not support custom recurrence. A meeting will only be created for the first reservation date.';
        $strings['LinkedAccounts'] = 'Linked Accounts';
        $strings['Linked'] = 'Linked';
        $strings['Unlinked'] = 'Unlinked';
        $strings['LinkAccount'] = 'Link Account';
        $strings['UnlinkAccount'] = 'Unlink Account';
        $strings['DateFormat'] = 'Date Format';
        $strings['TimeFormat'] = 'Time Format';
        $strings['ChangeOwner'] = 'Change Owner';
        $strings['CoOwners'] = 'Co-Owners';
        $strings['AddCoOwners'] = 'Add Co-Owners';
        $strings['ChangeCoOwners'] = 'Change Co-Owners';
        $strings['RemoveCoOwner'] = 'Remove Co-Owner';
        $strings['CoOwner'] = 'Co-Owner';
        $strings['MyReservations'] = 'My reservations';
        $strings['ShowLegend'] = 'Show Legend';
        $strings['HideLegend'] = 'Hide Legend';
        $strings['AttributeCategory'] = 'Attribute Category';
        $strings['MultipleSelect'] = 'Multiple Select';
        $strings['MustBeBookedWithOneWay'] = 'Must Be Booked With (One Way)';
        $strings['QuotaOn'] = 'On';
        $strings['QuotaEachPersonIn'] = 'Each Person In';
        $strings['QuotaIsLimitedTo'] = 'Is Limited To';
        $strings['QuotaStopEnforcement'] = 'Stop Enforcing';
        $strings['QuotaAheadOfCurrentTime'] = 'from the current time';
        $strings['Every'] = 'Every';
        $strings['Enforced'] = 'Enforced';
        $strings['Quotas'] = 'Quotas';
        $strings['UpdateQuota'] = 'Update Quota';
        $strings['UpTo'] = 'Up to';
        $strings['AddResourceMap'] = 'Add Resource Map';
        $strings['Map'] = 'Map';
        $strings['Published'] = 'Published';
        $strings['Draft'] = 'Draft';
        $strings['MapName'] = 'Map Name';
        $strings['MapImageInstructions'] = 'Choose map image file. Images only. Minimum width %s. Maximum width %s.';
        $strings['AdvancedSearchOptions'] = 'Advanced Search Options';
        $strings['CreditsAreNotEnabled'] = 'Credits are not enabled';
        $strings['JoinReservation'] = 'Join Reservation';
        $strings['DeleteReason'] = 'Delete Reason';
        $strings['AddOAuthProvider'] = 'Add OAuth Provider';
        $strings['OAuthProviderName'] = 'Provider Name';
        $strings['OAuthClientId'] = 'Client Id';
        $strings['OAuthClientSecret'] = 'Client Secret';
        $strings['AccessTokenGrantType'] = 'Access Token Grant Type';
        $strings['OAuthAuthorizationUrl'] = 'Authorization URL';
        $strings['OAuthAccessTokenUrl'] = 'Access Token URL';
        $strings['OAuthUserDetailsTokenUrl'] = 'User Details (Resource Owner) URL';
        $strings['FieldMappings'] = 'Field Mappings';
        $strings['UpdateOAuthProvider'] = 'Update OAuth Provider';
        $strings['LoginWith'] = 'Log In With';
        $strings['OAuthRedirectInstructions'] = 'OAuth providers may require this redirect URL when configuring a new client';
        $strings['TheValueForReservationAttribute'] = 'The value for reservation attribute';
        $strings['UpdateRule'] = 'Update Rule';
        $strings['OAuthProvider'] = 'OAuth Provider';
        $strings['ReservationColorRule'] = 'Reservation Color Rule';
        $strings['ReservationAttribute'] = 'Reservation Attribute';
        $strings['SelectAnAttribute'] = 'Select an attribute';
        $strings['Criteria'] = 'Criteria';
        $strings['ReleasedReservations'] = 'Released reservations';
        $strings['LoginActivationReminder'] = 'If you recently registered an account, you are required to activate it. Please check your email for an activation link.';
        $strings['ApprovedBy'] = 'Approved By';
        $strings['ApprovalDate'] = 'Approval Date';
        $strings['AddAllUsersConfirmation'] = 'Add all active users to this group?';
        // End Strings

        // Install
        $strings['InstallApplication'] = 'Install Booked Scheduler';
        $strings['IncorrectInstallPassword'] = 'Sorry, that password was incorrect.';
        $strings['SetInstallPassword'] = 'You must set an install password before the installation can be run.';
        $strings['InstallPasswordInstructions'] = 'In %s please set %s to a password which is random and difficult to guess, then return to this page.<br/>You can use %s';
        $strings['NoUpgradeNeeded'] = 'Booked is up to date. There is no upgrade needed.';
        $strings['ProvideInstallPassword'] = 'Please provide your installation password.';
        $strings['InstallPasswordLocation'] = 'This can be found at %s in %s.';
        $strings['VerifyInstallSettings'] = 'Verify the following default settings before continuing. Or you can change them in %s.';
        $strings['DatabaseName'] = 'Database Name';
        $strings['DatabaseUser'] = 'Database User';
        $strings['DatabaseHost'] = 'Database Host';
        $strings['DatabaseCredentials'] = 'You must provide credentials of a MySQL user who has privileges to create databases. If you do not know, contact your database admin. In many cases, root will work.';
        $strings['MySQLUser'] = 'MySQL User';
        $strings['InstallOptionsWarning'] = 'The following options will probably not work in a hosted environment. If you are installing in a hosted environment, use the MySQL wizard tools to complete these steps.';
        $strings['CreateDatabase'] = 'Create the database';
        $strings['CreateDatabaseUser'] = 'Create the database user';
        $strings['PopulateExampleData'] = 'Import sample data. Creates admin account: admin/password and user account: user/password';
        $strings['DataWipeWarning'] = 'Warning: This will delete any existing data';
        $strings['RunInstallation'] = 'Run Installation';
        $strings['UpgradeNotice'] = 'You are upgrading from version <b>%s</b> to version <b>%s</b>';
        $strings['RunUpgrade'] = 'Run Upgrade';
        $strings['Executing'] = 'Executing';
        $strings['StatementFailed'] = 'Failed. Details:';
        $strings['SQLStatement'] = 'SQL Statement:';
        $strings['ErrorCode'] = 'Error Code:';
        $strings['ErrorText'] = 'Error Text:';
        $strings['InstallationSuccess'] = 'Installation completed successfully!';
        $strings['RegisterAdminUser'] = 'Register your admin user. This is required if you did not import the sample data. Ensure that $conf[\'settings\'][\'allow.self.registration\'] = \'true\' in your %s file.';
        $strings['LoginWithSampleAccounts'] = 'If you imported the sample data, you can log in with admin/password for admin user or user/password for basic user.';
        $strings['InstalledVersion'] = 'You are now running version %s of Booked Scheduler';
        $strings['InstallUpgradeConfig'] = 'It is recommended to upgrade your config file';
        $strings['InstallationFailure'] = 'There were problems with the installation.  Please correct them and retry the installation.';
        $strings['ConfigureApplication'] = 'Configure Booked Scheduler';
        $strings['ConfigUpdateSuccess'] = 'Your config file is now up to date!';
        $strings['ConfigUpdateFailure'] = 'We could not automatically update your config file. Please overwrite the contents of config.php with the following:';
        $strings['ScriptUrlWarning'] = 'Your <em>script.url</em> setting may not be correct. It is currently <strong>%s</strong>, we think it should be <strong>%s</strong>';
        // End Install

        // Errors
        $strings['LoginError'] = 'We could not match your username or password';
        $strings['ReservationFailed'] = 'Your reservation could not be made';
        $strings['MinNoticeError'] = 'This reservation requires advance notice. The earliest date and time that can be reserved is %s.';
        $strings['MinNoticeErrorUpdate'] = 'Changing this reservation requires advance notice. Reservations before %s are not allowed to be changed.';
        $strings['MinNoticeErrorDelete'] = 'Deleting this reservation requires advance notice. Reservations before %s are not allowed to be deleted.';
        $strings['MaxNoticeError'] = 'This reservation cannot be made this far in the future. The latest date and time that can be reserved is %s.';
        $strings['MinDurationError'] = 'This reservation must last at least %s.';
        $strings['MaxDurationError'] = 'This reservation cannot last longer than %s.';
        $strings['ConflictingAccessoryDates'] = 'There are not enough of the following accessories:';
        $strings['NoResourcePermission'] = 'You do not have permission to access one or more of the requested resources.';
        $strings['ConflictingReservationDates'] = 'There are conflicting reservations on the following dates:';
        $strings['InstancesOverlapRule'] = 'Some instances of the reservation series overlap:';
        $strings['StartDateBeforeEndDateRule'] = 'The start date and time must be before the end date and time.';
        $strings['StartIsInPast'] = 'The start date and time cannot be in the past.';
        $strings['EmailDisabled'] = 'The administrator has disabled email notifications.';
        $strings['ValidLayoutRequired'] = 'Slots must be provided for all 24 hours of the day beginning and ending at 00:00.';
        $strings['CustomAttributeErrors'] = 'There are problems with the additional attributes you provided:';
        $strings['CustomAttributeRequired'] = '%s is a required field.';
        $strings['CustomAttributeInvalid'] = 'The value provided for %s is invalid.';
        $strings['AttachmentLoadingError'] = 'Sorry, there was a problem loading the requested file.';
        $strings['InvalidAttachmentExtension'] = 'You can only upload files of type: %s';
        $strings['InvalidStartSlot'] = 'The start date and time requested is not valid.';
        $strings['InvalidEndSlot'] = 'The end date and time requested is not valid.';
        $strings['MaxParticipantsError'] = '%s can only support %s participants.';
        $strings['MinParticipantsError'] = '%s requires at least %s participants.';
        $strings['ReservationCriticalError'] = 'There was a critical error saving your reservation. If this continues, contact your system administrator.';
        $strings['InvalidStartReminderTime'] = 'The start reminder time is not valid.';
        $strings['InvalidEndReminderTime'] = 'The end reminder time is not valid.';
        $strings['QuotaExceeded'] = 'Quota limit exceeded.';
        $strings['MultiDayRule'] = '%s does not allow reservations across days.';
        $strings['MultiDayRuleAll'] = 'Reservations across days are not allowed.';
        $strings['InvalidReservationData'] = 'There were problems with your reservation request.';
        $strings['PasswordError'] = 'Password must contain at least %s letters and at least %s numbers.';
        $strings['PasswordErrorRequirements'] = 'Password must contain a combination of at least %s upper and lower case letters and %s numbers.';
        $strings['NoReservationAccess'] = 'You are not allowed to change this reservation.';
        $strings['PasswordControlledExternallyError'] = 'Your password is controlled by an external system and cannot be updated here.';
        $strings['AccessoryResourceRequiredErrorMessage'] = 'Accessory %s can only be booked with resources %s';
        $strings['AccessoryMinQuantityErrorMessage'] = 'You must book at least %s of accessory %s';
        $strings['AccessoryMaxQuantityErrorMessage'] = 'You cannot book more than %s of accessory %s';
        $strings['AccessoryResourceAssociationErrorMessage'] = 'Accessory \'%s\' cannot be booked with the requested resources';
        $strings['NoResources'] = 'You have not added any resources.';
        $strings['ParticipationNotAllowed'] = 'You are not allowed to join this reservation.';
        $strings['ReservationCannotBeCheckedInTo'] = 'This reservation cannot be checked in to.';
        $strings['ReservationCannotBeCheckedOutFrom'] = 'This reservation cannot be checked out from.';
        $strings['InvalidEmailDomain'] = 'That email address is not from an allowed domain';
        $strings['TermsOfServiceError'] = 'You must accept the Terms of Service';
        $strings['UserNotFound'] = 'That user could not be found';
        $strings['ScheduleAvailabilityError'] = 'This schedule is available between %s and %s';
        $strings['ReservationNotFoundError'] = 'Reservation not found';
        $strings['ReservationNotAvailable'] = 'Reservation not available';
        $strings['TitleRequiredRule'] = 'Reservation title is required';
        $strings['DescriptionRequiredRule'] = 'Reservation description is required';
        $strings['WhatCanThisGroupManage'] = 'What can this group manage?';
        $strings['RegisteredAccountRequired'] = 'Only registered users can book reservations';
        $strings['InvalidNumberOfResourcesError'] = 'The maximum number of resources that can be reserved in a single reservation is %s';
        $strings['ScheduleTotalReservationsError'] = 'This schedule only allows %s resources to be reserved concurrently. This reservation would violate that limit on the following dates:';
        $strings['UserConcurrentLimitError'] = 'You can only have %s reservations at a time. This reservation would violate that limit on the following dates:';
        $strings['ResourceMustBeBookedWith'] = '%s must be booked with %s';
        $strings['ResourceCannotBeBookedWith'] = '%s cannot be booked with %s';
        $strings['ResourceCannotBeBookedAtSameTimeAs'] = '%s cannot be booked at the same time as %s';
        $strings['ReservationCannotBeBookedTogether '] = 'The following resources cannot be booked together';
        $strings['CorrectErrorsBelow'] = 'Please correct the errors below';
        $strings['ResourceImageUploadError'] = 'Image could not be uploaded. Check the type and size.';
        $strings['ReservationUploadError'] = 'File could not be uploaded. Check the type and size.';
        $strings['PastAutoreleaseError'] = 'This reservation has passed the check in time and cannot be modified.';
        $strings['CannotJoinReservation'] = 'You cannot join this reservation.';
        $strings['CannotDeclineReservation'] = 'You cannot decline this reservation.';
        $strings['WeHadTroubleProcessingYourRequest'] = 'We had trouble processing your request.';
        $strings['NewPasswordCannotBeTheSameAsOld'] = 'The new password cannot be the same as the old password';
        $strings['ResourceQRScanFailed'] = 'Resource could not be added. Either the QR code is not for a valid resource or you do not have permission to reserve this resource.';
        $strings['AccessoryQRScanFailed'] = 'Accessory could not be added. Either the QR code is not for a valid accessory or the accessory cannot be reserved.';
        $strings['TimezoneMismatchError'] = 'Your browser is set to a different timezone than your profile. This may cause problems with your reservation times.';
        $strings['AddResourceError'] = 'The resource is missing required fields';
        $strings['InvalidMeetingUrlError'] = 'The meeting link url is invalid';
        $strings['ErrorConnectingToExternalMeeting'] = 'We could not connect your account to %s. Please refresh this page and reconnect your account.';
        $strings['MapImageError'] = 'Images only. Minimum width %s. Maximum width %s.';
        $strings['OAuthLoginError'] = 'Your login request could not be processed. Please try again.';
        // End Errors

        // Page Titles
        $strings['CreateReservation'] = 'New Reservation';
        $strings['EditReservation'] = 'Update Reservation';
        $strings['LogIn'] = 'Log In';
        $strings['ManageReservations'] = 'Reservations';
        $strings['ManageReservationSettings'] = 'Reservation Settings';
        $strings['AwaitingActivation'] = 'Awaiting Activation';
        $strings['PendingApproval'] = 'Pending Approval';
        $strings['ManageSchedules'] = 'Schedules';
        $strings['ManageResources'] = 'Resources';
        $strings['ManageAccessories'] = 'Accessories';
        $strings['ManageUsers'] = 'Users';
        $strings['ManageGroups'] = 'Groups';
        $strings['ManageQuotas'] = 'Quotas';
        $strings['ManageBlackouts'] = 'Blackout Times';
        $strings['MyDashboard'] = 'My Dashboard';
        $strings['ServerSettings'] = 'Server Settings';
        $strings['Dashboard'] = 'Dashboard';
        $strings['Help'] = 'Help';
        $strings['Administration'] = 'Administration';
        $strings['About'] = 'About';
        $strings['Bookings'] = 'Bookings';
        $strings['Schedule'] = 'Schedule';
        $strings['Account'] = 'Account';
        $strings['EditProfile'] = 'Edit My Profile';
        $strings['FindAnOpening'] = 'Find An Opening';
        $strings['OpenInvitations'] = 'Open Invitations';
        $strings['ResourceCalendar'] = 'Resource Calendar';
        $strings['Reservation'] = 'New Reservation';
        $strings['Install'] = 'Installation';
        $strings['ChangePassword'] = 'Change Password';
        $strings['MyAccount'] = 'My Account';
        $strings['Profile'] = 'Profile';
        $strings['ApplicationManagement'] = 'Application Management';
        $strings['ForgotPassword'] = 'Forgot Password';
        $strings['NotificationPreferences'] = 'Notification Preferences';
        $strings['ManageAnnouncements'] = 'Announcements';
        $strings['Responsibilities'] = 'Responsibilities';
        $strings['GroupReservations'] = 'Group Reservations';
        $strings['ResourceReservations'] = 'Resource Reservations';
        $strings['Customization'] = 'Customization';
        $strings['Attributes'] = 'Attributes';
        $strings['AccountActivation'] = 'Account Activation';
        $strings['ScheduleReservations'] = 'Schedule Reservations';
        $strings['Reports'] = 'Reports';
        $strings['GenerateReport'] = 'Create New Report';
        $strings['MySavedReports'] = 'My Saved Reports';
        $strings['CommonReports'] = 'Common Reports';
        $strings['ViewDay'] = 'View Day';
        $strings['Group'] = 'Group';
        $strings['ManageConfiguration'] = 'Application Configuration';
        $strings['LookAndFeel'] = 'Look and Feel';
        $strings['ManageResourceGroups'] = 'Resource Groups';
        $strings['ManageResourceTypes'] = 'Resource Types';
        $strings['ManageResourceStatus'] = 'Resource Statuses';
        $strings['ReservationColors'] = 'Reservation Colors';
        $strings['SearchReservations'] = 'Search Reservations';
        $strings['ManagePayments'] = 'Payments';
        $strings['ViewCalendar'] = 'View Calendar';
        $strings['DataCleanup'] = 'Data Cleanup';
        $strings['ManageEmailTemplates'] = 'Manage Email Templates';
        $strings['ManageMonitorViews'] = 'Monitor Views';
        $strings['ConfirmAccount'] = 'Security Check';
        $strings['FirstLogin'] = 'Welcome to Booked!';
        $strings['ReservationsNav'] = 'Reservations';
        $strings['ManageMaps'] = 'Resource Maps';
        $strings['ResourceMaps'] = 'Resource Maps';
        $strings['ManageOAuth'] = 'OAuth Providers';
        // End Page Titles

        // Day representations
        $strings['DaySundaySingle'] = 'S';
        $strings['DayMondaySingle'] = 'M';
        $strings['DayTuesdaySingle'] = 'T';
        $strings['DayWednesdaySingle'] = 'W';
        $strings['DayThursdaySingle'] = 'T';
        $strings['DayFridaySingle'] = 'F';
        $strings['DaySaturdaySingle'] = 'S';

        $strings['DaySundayAbbr'] = 'Sun';
        $strings['DayMondayAbbr'] = 'Mon';
        $strings['DayTuesdayAbbr'] = 'Tue';
        $strings['DayWednesdayAbbr'] = 'Wed';
        $strings['DayThursdayAbbr'] = 'Thu';
        $strings['DayFridayAbbr'] = 'Fri';
        $strings['DaySaturdayAbbr'] = 'Sat';
        // End Day representations

        // Email Subjects
        $strings['ReservationApprovedSubject'] = 'Your reservation has been approved';
        $strings['ReservationCreatedSubject'] = 'Your reservation was created';
        $strings['ReservationUpdatedSubject'] = 'Your reservation was updated';
        $strings['ReservationDeletedSubject'] = 'Your reservation was deleted';
        $strings['ReservationCreatedAdminSubject'] = 'Notification: A reservation was created';
        $strings['ReservationUpdatedAdminSubject'] = 'Notification: A reservation was updated';
        $strings['ReservationDeleteAdminSubject'] = 'Notification: A reservation was deleted';
        $strings['ReservationApprovalAdminSubject'] = 'Notification: Reservation requires your approval';
        $strings['ParticipantAddedSubject'] = 'Reservation participation notification';
        $strings['ParticipantDeletedSubject'] = 'Reservation removed';
        $strings['InviteeAddedSubject'] = 'Reservation invitation';
        $strings['ResetPasswordRequest'] = 'Password reset request';
        $strings['ActivateYourAccount'] = 'Please activate your account';
        $strings['ReportSubject'] = 'Your requested report (%s)';
        $strings['ReservationStartingSoonSubject'] = 'Reservation for %s is starting soon';
        $strings['ReservationEndingSoonSubject'] = 'Reservation for %s is ending soon';
        $strings['UserAdded'] = 'A new user has been added';
        $strings['UserDeleted'] = 'User account for %s was deleted by %s';
        $strings['GuestAccountCreatedSubject'] = 'Your %s account details';
        $strings['AccountCreatedSubject'] = 'Your %s account details';
        $strings['InviteUserSubject'] = '%s has invited you to join %s';
        $strings['ReservationApprovedSubjectWithResource'] = 'Reservation has been approved for %s';
        $strings['ReservationCreatedSubjectWithResource'] = 'Reservation created for %s';
        $strings['ReservationUpdatedSubjectWithResource'] = 'Reservation updated for %s';
        $strings['ReservationDeletedSubjectWithResource'] = 'Reservation deleted for %s';
        $strings['ReservationCreatedAdminSubjectWithResource'] = 'Notification: Reservation Created for %s';
        $strings['ReservationUpdatedAdminSubjectWithResource'] = 'Notification: Reservation Updated for %s';
        $strings['ReservationDeleteAdminSubjectWithResource'] = 'Notification: Reservation Deleted for %s';
        $strings['ReservationApprovalAdminSubjectWithResource'] = 'Notification: Reservation for %s requires your approval';
        $strings['ParticipantAddedSubjectWithResource'] = '%s added you to a reservation for %s';
        $strings['ParticipantUpdatedSubjectWithResource'] = '%s updated a reservation for %s';
        $strings['ParticipantDeletedSubjectWithResource'] = '%s deleted a reservation for %s';
        $strings['InviteeAddedSubjectWithResource'] = '%s invited you to a reservation for %s';
        $strings['MissedCheckinEmailSubject'] = 'Missed checkin for %s';
        $strings['MissedCheckoutEmailSubject'] = 'Missed checkout for %s';
        $strings['ReservationExtendedEmailSubject'] = 'Reservation for %s was automatically extended';
        $strings['ReservationShareSubject'] = '%s shared a reservation for %s';
        $strings['ReservationSeriesEndingSubject'] = 'Reservation series for %s is ending on %s';
        $strings['ReservationParticipantAccept'] = '%s has accepted your reservation invitation for %s on %s';
        $strings['ReservationParticipantDecline'] = '%s has declined your reservation invitation for %s on %s';
        $strings['ReservationParticipantJoin'] = '%s has joined your reservation for %s on %s';
        $strings['ReservationAvailableSubject'] = '%s is available on %s';
        $strings['ResourceStatusChangedSubject'] = 'The availability of %s has changed';
        $strings['PasswordUpdatedByAdminSubject'] = 'Your %s password has been changed';
        $strings['OneTimePasscodeSubject'] = 'Your %s one time passcode';
        $strings['ReservationOwnershipChangedSubject'] = 'Reservations have been transferred to you';
        $strings['CoOwnerAddedSubjectWithResource'] = '%s added you as a co-owner to a reservation for %s';
        $strings['CoOwnerUpdatedSubjectWithResource'] = '%s updated a reservation that you co-own for %s';
        $strings['CoOwnerDeletedSubjectWithResource'] = '%s deleted a reservation that you co-own for %s';
        $strings['PasswordUpdatedByUserSubject'] = 'Your Booked password was updated';
        // End Email Subjects

        // SMS
        $strings['SMSMessageReservationCreated'] = 'Reservation for %s at %s was created. %s';
        $strings['SMSMessageReservationApproved'] = 'Reservation for %s at %s was approved. %s';
        $strings['SMSMessageReservationDeleted'] = 'Reservation for %s at %s was deleted. %s';
        $strings['SMSMessageReservationUpdated'] = 'Reservation for %s at %s was updated. %s';
        $strings['SMSMessageReservationStartReminder'] = 'Reservation for %s is starting at %s. %s';
        $strings['SMSMessageReservationEndReminder'] = 'Reservation for %s is ending at %s. %s';
        $strings['SMSMessageReservationSeriesEndingReminder'] = 'The last reservation in the series for %s is on %s. %s';
        $strings['SMSMessageOTP'] = 'Your Booked one time passcode is %s';
        $strings['SMSMessageOTPConfirm'] = 'Thank you for confirming your phone number. You can manage your Booked SMS settings in your Notification Preferences.';
        $strings['SMSMessageReservationMissedCheckin'] = 'You have missed the reservation check in time for %s at %s. %s';
        $strings['SMSMessageReservationMissedCheckout'] = 'You have missed the reservation check out time for %s at %s. %s';
        // End SMS

        $this->Strings = $strings;

        return $this->Strings;
    }

    /**
     * @return array
     */
    protected function _LoadDays()
    {
        $days = array();

        /***
         * DAY NAMES
         * All of these arrays MUST start with Sunday as the first element
         * and go through the seven day week, ending on Saturday
         ***/
        // The full day name
        $days['full'] = array('Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday');
        // The three letter abbreviation
        $days['abbr'] = array('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');
        // The two letter abbreviation
        $days['two'] = array('Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa');
        // The one letter abbreviation
        $days['letter'] = array('S', 'M', 'T', 'W', 'T', 'F', 'S');

        $this->Days = $days;

        return $this->Days;
    }

    /**
     * @return array
     */
    protected function _LoadMonths()
    {
        $months = array();

        /***
         * MONTH NAMES
         * All of these arrays MUST start with January as the first element
         * and go through the twelve months of the year, ending on December
         ***/
        // The full month name
        $months['full'] = array('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December');
        // The three letter month name
        $months['abbr'] = array('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');

        $this->Months = $months;

        return $this->Months;
    }

    /**
     * @return array
     */
    protected function _LoadLetters()
    {
        $this->Letters = array('A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z');

        return $this->Letters;
    }

    protected function _GetHtmlLangCode()
    {
        return 'en';
    }
}